@@ -10,22 +10,22 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{chain} = {
     v => 1.1,
     summary => 'Chain several dux functions together',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 Currently works for itemfunc only.
 
 See also the <pm:Data::Unixish::Apply> function, which is related.
 
-_
+MARKDOWN
     args => {
         %common_args,
         functions => {
@@ -34,12 +34,12 @@ _
                 'str*',
                 ['array*', min_len=>1, elems=>['str*','hash*']],
             ]]],
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 Each element must either be function name (like `date`) or a 2-element array
 containing the function name and its arguments (like `[bool, {style: dot}]`).
 
-_
+MARKDOWN
             req     => 1,
             pos     => 0,
             greedy  => 1,
@@ -133,7 +133,7 @@ Data::Unixish::chain - Chain several dux functions together
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::chain (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::chain (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -231,7 +231,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
