@@ -11,23 +11,23 @@ require Data::Unixish; # for siduxs
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{cond} = {
     v => 1.1,
     summary => 'Apply dux function conditionally',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This dux function takes a condition (a Perl code/expression) and one or two
 other dux functions (A and B). Condition will be evaluated for each item (where
 `$_` will be set to the current item). If condition evaluates to true, then A is
 applied to the item, else B. All the dux functions must be itemfunc.
 
-_
+MARKDOWN
     args => {
         %common_args,
         if => {
@@ -108,7 +108,7 @@ Data::Unixish::cond - Apply dux function conditionally
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::cond (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::cond (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -215,7 +215,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
