@@ -9,21 +9,21 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{lins} = {
     v => 1.1,
     summary => 'Add some text at the beginning of each line of text',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This is sort of a counterpart for ltrim, which removes whitespace at the
 beginning (left) of each line of text.
 
-_
+MARKDOWN
     args => {
         %common_args,
         text => {
@@ -70,7 +70,7 @@ Data::Unixish::lins - Add some text at the beginning of each line of text
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::lins (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::lins (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -168,7 +168,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
