@@ -9,9 +9,9 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
@@ -22,11 +22,11 @@ $SPEC{linum} = {
         %common_args,
         format => {
             summary => 'Sprintf-style format to use',
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 Example: `%04d|`.
 
-_
+MARKDOWN
             schema  => [str => default=>'%4s|'],
             cmdline_aliases => { f=>{} },
         },
@@ -37,7 +37,7 @@ _
         },
         blank_empty_lines => {
             schema => [bool => default=>1],
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 Example when set to false:
 
@@ -53,7 +53,7 @@ Example when set to true:
     3|sub blah {
     4|    my %args = @_;
 
-_
+MARKDOWN
             cmdline_aliases => {
                 b => {},
                 B => {
@@ -122,7 +122,7 @@ Data::Unixish::linum - Add line numbers
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::linum (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::linum (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -241,7 +241,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
