@@ -14,9 +14,9 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
@@ -38,13 +38,13 @@ my %styles = (
 $SPEC{num} = {
     v => 1.1,
     summary => 'Format number',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 Observe locale environment variable settings.
 
 Undef and non-numbers are ignored.
 
-_
+MARKDOWN
     args => {
         %common_args,
         style => {
@@ -60,13 +60,13 @@ _
         },
         thousands_sep => {
             summary => 'Use a custom thousand separator character',
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 Default is from locale (e.g. dot "." for en_US, etc).
 
 Use empty string "" if you want to disable printing thousands separator.
 
-_
+MARKDOWN
             schema => ['str*'],
         },
         prefix => {
@@ -176,7 +176,7 @@ Data::Unixish::num - Format number
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::num (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -307,7 +307,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
