@@ -9,9 +9,9 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
@@ -23,13 +23,13 @@ my %charsets = (
     'AZaz'   => 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz',
     'AZaz09' => 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789',
 );
-my $charsets_desc = <<'_';
+my $charsets_desc = <<'MARKDOWN';
 
 `az` is basic Latin lowercase letters. `AZ` uppercase letters. `AZaz` lowercase
 and uppercase letters. `AZaz09` lowercase + uppercase letters + Arabic numbers.
 `09` numbers.
 
-_
+MARKDOWN
 
 $SPEC{randstr} = {
     v => 1.1,
@@ -111,7 +111,7 @@ Data::Unixish::randstr - Generate a stream of random strings
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::randstr (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::randstr (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -220,7 +220,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
