@@ -9,21 +9,21 @@ use warnings;
 use Data::Unixish::Util qw(%common_args);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{sort} = {
     v => 1.1,
     summary => 'Sort items',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 By default sort ascibetically, unless `numeric` is set to true to sort
 numerically.
 
-_
+MARKDOWN
     args => {
         %common_args,
         numeric => {
@@ -50,13 +50,13 @@ _
         key_element => {
             summary => 'Sort using an array element',
             schema => 'uint*',
-            description => <<'_',
+            description => <<'MARKDOWN',
 
 If specified, `sort` will assume the item is an array and will sort using the
 <key_element>'th element (zero-based) as key. If an item turns out to not be an
 array, the item itself is used as key.
 
-_
+MARKDOWN
         },
     },
     tags => [qw/ordering/],
@@ -125,7 +125,7 @@ Data::Unixish::sort - Sort items
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::sort (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::sort (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -245,7 +245,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
