@@ -12,16 +12,16 @@ use POSIX qw(locale_h);
 use Scalar::Util 'looks_like_number';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{sprintf} = {
     v => 1.1,
     summary => 'Apply sprintf() on input',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 Array will also be processed (all the elements are fed to sprintf(), the result
 is a single string), unless `skip_array` is set to true.
@@ -30,7 +30,7 @@ Non-numbers can be skipped if you use `skip_non_number`.
 
 Undef, hashes, and other non-scalars are ignored.
 
-_
+MARKDOWN
     args => {
         %common_args,
         format => {
@@ -119,7 +119,7 @@ Data::Unixish::sprintf - Apply sprintf() on input
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::sprintf (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::sprintf (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -233,7 +233,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
