@@ -6,21 +6,21 @@ use syntax 'each_on_array'; # to support perl < 5.12
 use warnings;
 #use Log::Any '$log';
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
-our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
-
 use Data::Unixish::Util qw(%common_args);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2025-02-24'; # DATE
+our $DIST = 'Data-Unixish'; # DIST
+our $VERSION = '1.574'; # VERSION
+
 our %SPEC;
 
 $SPEC{trim} = {
     v => 1.1,
     summary => 'Strip whitespace at the beginning and end of each line of text',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
-_
+MARKDOWN
     args => {
         %common_args,
         strip_newline => {
@@ -70,7 +70,7 @@ Data::Unixish::trim - Strip whitespace at the beginning and end of each line of
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::trim (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::trim (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -161,7 +161,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
