@@ -13,16 +13,16 @@ use Text::ANSI::WideUtil qw(ta_mbtrunc);
 use Text::WideChar::Util qw(mbtrunc);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-23'; # DATE
+our $DATE = '2025-02-24'; # DATE
 our $DIST = 'Data-Unixish'; # DIST
-our $VERSION = '1.573'; # VERSION
+our $VERSION = '1.574'; # VERSION
 
 our %SPEC;
 
 $SPEC{trunc} = {
     v => 1.1,
     summary => 'Truncate string to a certain column width',
-    description => <<'_',
+    description => <<'MARKDOWN',
 
 This function can handle text containing wide characters and ANSI escape codes.
 
@@ -30,7 +30,7 @@ Note: to truncate by character instead of column width (note that wide
 characters like Chinese can have width of more than 1 column in terminal), you
 can turn of `mb` option even when your text contains wide characters.
 
-_
+MARKDOWN
     args => {
         %common_args,
         width => {
@@ -92,7 +92,7 @@ Data::Unixish::trunc - Truncate string to a certain column width
 
 =head1 VERSION
 
-This document describes version 1.573 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2023-09-23.
+This document describes version 1.574 of Data::Unixish::trunc (from Perl distribution Data-Unixish), released on 2025-02-24.
 
 =head1 SYNOPSIS
 
@@ -197,7 +197,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2023, 2019, 2017, 2016, 2015, 2014, 2013, 2012 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2025 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
